@@ -28,34 +28,21 @@ SCRIPT_NAME=$(basename $0)
 #can make the upgrade script overridable (if a different target will be used)
 UPGRADE_SCRIPT=${UPGRADE_SCRIPT:-/root/tripleo_upgrade_node.sh}
 #allow override incase the ssh user is not 'heat-admin' - must be able to sudo
-STACK_NAME_DEFAULT="overcloud"
-STACK_NAME=${STACK_NAME:-$STACK_NAME_DEFAULT}
-UPGRADE_NODE_USER_DEFAULT="heat-admin"
-UPGRADE_NODE_USER=${UPGRADE_NODE_USER:-$UPGRADE_NODE_USER_DEFAULT}
+UPGRADE_NODE_USER=${UPGRADE_NODE_USER:-"heat-admin"}
 UPGRADE_NODE=""
 QUERY_NODE=""
+SCRIPT=""
 HOSTNAME=""
 IP_ADDR=""
-INVENTORY=""
-ANSIBLE_OPTS="" # e.g. "--skip-tags validation"
+
 function show_options {
     echo "Usage: $SCRIPT_NAME"
     echo
     echo "Options:"
     echo "  -h|--help                    -- print this help."
-    echo "  -u|--upgrade <nova node>     -- nova node name or id or ctlplane IP"
-    echo "                                  to upgrade."
+    echo "  -u|--upgrade <nova node>     -- nova node name or id or ctlplane IP to upgrade"
     echo "  -q|--query <nova node>       -- check if the node is ACTIVE and tail"
-    echo "                                  yum.log for any package update info."
-    echo "  -s|--stack-name <stack name> -- the stack name, defaults to $STACK_NAME_DEFAULT"
-    echo "  -I|--inventory <path>        -- use the specified tripleo ansible "
-    echo "                                  inventory (yaml format)."
-    echo "  -O|--ansible-opts \"opts\"   -- specify extra options to be passed "
-    echo "                                  to ansible-playbook e.g. \"-vvv\" or "
-    echo "                                  \"-vvv --skip-tags validation\"."
-    echo "  -U|--overcloud-user <name>   -- the user with which to ssh to the"
-    echo "                                  target upgrade node - defaults to"
-    echo "                                  $UPGRADE_NODE_USER_DEFAULT."
+    echo "                                  yum.log for any package update info"
     echo
     echo "Invoke the /root/tripleo_upgrade_node.sh script on roles that have"
     echo "the 'disable_upgrade_deployment' flag set true and then download and"
@@ -78,12 +65,6 @@ function show_options {
     echo "    upgrade-non-controller.sh --upgrade overcloud-compute-0 "
     echo "    upgrade-non-controller.sh -u 734eea90-087b-4f12-9cd9-4807da83ea78 "
     echo "    upgrade-non-controller.sh -u 192.168.24.15 "
-    echo "    upgrade-non-controller.sh -U stack -u 192.168.24.15 -s overcloud"
-    echo "    upgrade-non-controller.sh -U stack -u 192.168.24.16 \ "
-    echo "                              -I /home/stack/tripleo-ansible-inventory"
-    echo "    upgrade-non-controller.sh -U stack -u 192.168.24.16 \ "
-    echo "                              -I /home/stack/tripleo-ansible-inventory \ "
-    echo "                              -O \"-vvv --skip-tags validation\" "
     echo
     echo "You can run on multiple nodes in parallel: "
 
@@ -95,7 +76,7 @@ function show_options {
     exit $1
 }
 
-TEMP=`getopt -o h,u:,q:,s:,U:,I:,O: -l help,upgrade:,query:,stack-name:,overcloud-user:,inventory:,ansible-opts: -n $SCRIPT_NAME -- "$@"`
+TEMP=`getopt -o h,u:,q: -l help,upgrade:,query:,script: -n $SCRIPT_NAME -- "$@"`
 
 if [ $? != 0 ]; then
     echo "Terminating..." >&2
@@ -109,11 +90,8 @@ while true ; do
     case "$1" in
         -h | --help ) show_options 0 >&2;;
         -u | --upgrade ) UPGRADE_NODE="$2" ; shift 2 ;;
+        -s | --script ) SCRIPT="$2"; shift 2 ;;
         -q | --query ) QUERY_NODE="$2" ; shift 2 ;;
-        -s | --stack-name ) STACK_NAME="$2" ; shift 2 ;;
-        -U | --overcloud-user ) UPGRADE_NODE_USER="$2"; shift 2;;
-        -I | --inventory ) INVENTORY="$2"; shift 2;;
-        -O | --ansible-opts ) ANSIBLE_OPTS="$2"; shift 2;;
         -- ) shift ; break ;;
         * ) echo "Error: unsupported option $1." ; exit 1 ;;
     esac
@@ -166,46 +144,18 @@ function find_node_by_name_id_or_ip {
   set -e
 }
 
-# Generate static tripleo ansible inventory. This is mainly to deal with different
-# ssh user for the ansible playbooks, e.g. in a split stack environment.
-# $1 is the path for to write the tripleo-ansible-inventory to
-function get_static_inventory {
-  local config_dir=$1
-  if [ -d "$config_dir" ] ;then
-    local inventory_args=" --plan $STACK_NAME --static-inventory $config_dir/tripleo-ansible-inventory"
-    if [[ $UPGRADE_NODE_USER != $UPGRADE_NODE_USER_DEFAULT ]]; then
-      inventory_args+=" --ansible_ssh_user $UPGRADE_NODE_USER"
-    fi
-    log "Generating static tripleo-ansible-inventory with these args: $inventory_args"
-    /usr/bin/tripleo-ansible-inventory $inventory_args
-  else
-    log "ERROR can't generate tripleo-ansible-inventory - cannot find $config_dir"
-    exit 1
-  fi
-}
-
-function run_ansible_playbook {
-    local playbook=$UPGRADE_NODE/$1
-    full_args=" -b --limit $HOSTNAME --inventory $INVENTORY $ANSIBLE_OPTS $playbook"
-    log "Running ansible-playbook with $full_args"
-    ansible-playbook $full_args 2>&1 | tee -a  $LOGFILE
-}
-
 if [ -n "$UPGRADE_NODE" ]; then
   find_node_by_name_id_or_ip $UPGRADE_NODE
   log "Executing $UPGRADE_SCRIPT on $IP_ADDR"
   ssh $UPGRADE_NODE_USER@$IP_ADDR sudo $UPGRADE_SCRIPT 2>&1 | tee -a $LOGFILE
   log "Clearing any existing dir $UPGRADE_NODE and downloading config"
   rm -rf $UPGRADE_NODE
-  openstack overcloud config download --name "$STACK_NAME" --config-dir "$UPGRADE_NODE"
+  openstack overcloud config download --config-dir "$UPGRADE_NODE"
   config_dir=$(ls -1 $UPGRADE_NODE)
-  if [ -z "$INVENTORY" ]; then
-    get_static_inventory $UPGRADE_NODE/$config_dir
-    INVENTORY=$UPGRADE_NODE/$config_dir/tripleo-ansible-inventory
-  fi
-  for book in upgrade_steps_playbook.yaml deploy_steps_playbook.yaml ; do
-    run_ansible_playbook $config_dir/$book
-  done
+  log "Starting the upgrade steps playbook run for $HOSTNAME from $UPGRADE_NODE/$config_dir/"
+  ansible-playbook -b -i /usr/bin/tripleo-ansible-inventory $UPGRADE_NODE/$config_dir/upgrade_steps_playbook.yaml --limit $HOSTNAME
+  log "Starting the deploy-steps-playbook run for $HOSTNAME from $UPGRADE_NODE/$config_dir/"
+  ansible-playbook -b -i /usr/bin/tripleo-ansible-inventory $UPGRADE_NODE/$config_dir/deploy_steps_playbook.yaml --limit $HOSTNAME
 fi
 
 if [ -n "$QUERY_NODE" ]; then
